@@ -3,6 +3,7 @@ from api.common import *
 requests.eshost	= os.getenv('eshost', '172.17.0.1:9200') #wrask.com
 
 iphrase = lambda q="_be in force|_wish it to be", cp='c4-*', field='postag': [ (hyb, requests.post(f"http://{requests.eshost}/{cp}/_search", json={   "query": {  "match_phrase": { field: hyb    }   } } ).json()['hits']['total']['value'] ) for hyb in q.strip().split('|') ]
+ihyb	= lambda hyb="_consider to _VERB", fld='skenp', cp='dic', host='hw13.jukuu.com:9200': requests.get(f"http://{host}/{cp}/_search",json={"query": {"match_phrase": {fld: hyb }}, "size":0}).json()["hits"]["total"]["value"]
 iterm  = lambda term="NOUN:force", cp='en', field='kps':requests.post(f"http://{requests.eshost}/{cp}/_search", json={   "query": {  "term": { field: term    }   } } ).json()['hits']['total']['value']
 sntsum = lambda cp='clec': requests.post(f"http://{requests.eshost}/_sql", json={"query":f"select count(*) from {cp} where type='snt'"}).json()['rows'][0][0]
 match_phrase = lambda hyb="_be in force", cp='en', field='postag': requests.post(f"http://{requests.eshost}/{cp}/_search", json={   "query": {  "match_phrase": { field: hyb    }   } } ).json()
@@ -440,4 +441,13 @@ var hyb = 'the_[^ ]* [^ ]*_NNS_[^ ]* of_[^ ]*'
 console.log(s.search(hyb))
 ==> 4 
 
+The accused's intention had to be considered to determine whether he wished to use it to inflict injury. | add: not consider_VBN 
+GET /dic/_search
+{
+  "query": {
+    "match_phrase": {
+      "skenp": "_consider to _VERB"    }
+  }, "size":0
+}
+
 '''
\ No newline at end of file
