@@ -397,7 +397,7 @@ def es_postag(doc):
 def es_hyb(doc): 
 	from dic.oneself import oneself 
 	arr = [ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]
-	return "_^ " + ' '.join( [f"{s}_*" for s in arr]) # support :  a * book | a * * book
+	return "_^ " + ' '.join( [s if '_PUNCT' in s else f"{s}_*" for s in arr]) # support :  a _* book | a * * book
 
 # added 2023.1.16, not tested yet
 cl_root = lambda t: t.dep_ != 'ROOT' and ( (t.pos_ == 'VERB' and t.tag_ != 'VBN')  or (t.pos_ == 'AUX' and t.lemma_ == 'be') )
@@ -440,22 +440,22 @@ def attach_cl(doc): #2023.1.23
 			start = children[0].i  	
 			end = children[-1].i 
 			cl_len = end - start + 1 
-			doc[start].ent_id_ = f'_CL{cl_len}'  # add cl_root ? 
+			doc[start].ent_id_ = f'_CL{v.dep_}{cl_len}'  # add cl_root ? # S.advcl ,  S.conj 
 		except Exception as e:
 			print ( "attach_cl ex:", e, v )
 	return doc 
 
 def skenp_tok(t): 
 	from dic.oneself import oneself 
-	pair = f"_{t.lemma_}_NP_{t.dep_}" if t.ent_type_ == 'NP' else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"
-	if t.ent_id_.startswith("_CL"): pair = pair + t.ent_id_
+	#pair = f"_{t.lemma_}_NP_{t.dep_}" if t.ent_type_ == 'NP' else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"
+	pair = f"_{t.lemma_}_NP_{t.dep_}" if (t.ent_type_ == 'NP' and t.lemma_ not in ('that','which')) else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"
+	if t.ent_id_.startswith("_CL") and not 'ROOT' in t.ent_id_: pair = pair + t.ent_id_
 	return pair 
 
 def es_skenp(doc):
 	#merge_ccomp(doc) # merge_leave_cl(doc) 
 	merge_np(doc) 
 	attach_cl(doc)
-	#return "_^ " + ' '.join([ f"_{t.lemma_}_NP_{t.dep_}" if t.ent_type_ == 'NP' else f"_CL_{t.dep_}" if t.ent_type_.startswith("S.") else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"  for t in doc]) 
 	return "_^ " + ' '.join([ skenp_tok(t) for t in doc]) 
 
 @Language.component("merge_prt")
@@ -804,25 +804,25 @@ postag_func_kp = {  # doc,start, end, tag
 	"vpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
 				f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}", 
-				f"{d[e-1].lemma_}/NOUN|vpn:{d[s].lemma_} {d[s+1:e].text}",  # force/NOUN|vpn:come into force
+				f"{d[e-1].lemma_}/NOUN|vpn:_{d[s].lemma_} {d[s+1:e].text}",  # force/NOUN|vpn:come into force
 				]} }) , # _VERB with force, jump over the dog? 
 	"bpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
 			f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}",
-			f"{d[e-1].lemma_}/NOUN|vpn:{d[s].lemma_} {d[s+1:e].text}", ] }}) , # be with force, be is a VERB
+			f"{d[e-1].lemma_}/NOUN|vpn:_{d[s].lemma_} {d[s+1:e].text}", ] }}) , # be with force, be is a VERB
 	"vnp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vnp", f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} _NOUN {d[s+2].text}",
 				f"{d[s+1].lemma_}:NOUN:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:NOUN|vnp", f"{d[s+1].lemma_}:NOUN:vnp|_VERB {d[s+1:e].text}",
-				f"{d[s].lemma_}/VERB|vnp:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
+				f"{d[s].lemma_}/VERB|vnp:_{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"vp":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vp|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vp", f"{d[s+1].lemma_}:{d[s+1].pos_}:vp|_VERB {d[s+1].text}",
-				 f"{d[s].lemma_}/VERB|vp:{d[s].lemma_} {d[s+1].text}",	] }}) ,
+				 f"{d[s].lemma_}/VERB|vp:_{d[s].lemma_} {d[s+1].text}",	] }}) ,
 	"vpp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpp"
-				 f"{d[s].lemma_}/VERB|vpp:{d[s].lemma_} {d[s+1:e].text}", ] }}) ,
+				 f"{d[s].lemma_}/VERB|vpp:_{d[s].lemma_} {d[s+1:e].text}", ] }}) ,
 	"vpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpg|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vpg", f"{d[s].lemma_}:VERB:vpg|_{d[s].lemma_} {d[s+1].text} _VBG", 
-			f"{d[s].lemma_}/VERB|vpg:{d[s].lemma_} {d[s+1].text} _VBG"] }}) ,
+			f"{d[s].lemma_}/VERB|vpg:_{d[s].lemma_} {d[s+1].text} _VBG"] }}) ,
 	"pn":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:NOUN:pn|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN|pn",
 			f"{d[s+1].lemma_}/NOUN|pn:{d[s:e].text.lower()}", ] }}) ,
@@ -835,28 +835,28 @@ postag_func_kp = {  # doc,start, end, tag
 		{"nac": [f"{d[s+1].lemma_}:ADJ:batv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|batv", f"{d[s+1].lemma_}:ADJ:batv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB"]}}) ,  
 	"bepv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:VERB:bepv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|bepv", f"{d[s+1].lemma_}:VERB:bepv|_be {d[s+1:e-1].text} _VERB",
-			f"{d[s+1].lemma_}/VERB|bepv:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
+			f"{d[s+1].lemma_}/VERB|bepv:_{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
 	"betv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:VERB:betv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|betv", f"{d[s+1].lemma_}:VERB:betv|_be {d[s+1:e-1].text} _VERB",
-		     f"{d[s+1].lemma_}/VERB|betv:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
+		     f"{d[s+1].lemma_}/VERB|betv:_{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
 	"bap": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:ADJ:bap|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bap",
-				f"{d[s+1].lemma_}/ADJ|bap:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
+				f"{d[s+1].lemma_}/ADJ|bap:_{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"bep": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:VERB:bep|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:VERB|bep",
-				f"{d[s+1].lemma_}/VERB|bep:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
+				f"{d[s+1].lemma_}/VERB|bep:_{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"vop": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vop|{d[s].lemma_} oneself {d[e-1].text}", f"{d[s].lemma_}:VERB|vop",  f"{d[s].lemma_}:VERB:vop|_{d[s].lemma_} _oneself {d[e-1].text}",
-			f"{d[s].lemma_}/VERB|vop:{d[s].lemma_} oneself {d[e-1].text.lower()}",]}}) ,
+			f"{d[s].lemma_}/VERB|vop:_{d[s].lemma_} _oneself {d[e-1].text.lower()}",]}}) ,
 	"vtv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vtv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB:vtv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB", f"{d[s].lemma_}:VERB|vtv", f"{d[e-1].lemma_}:VERB|~vtv", f"{d[e-1].lemma_}:VERB:~vtv|{d[s].lemma_}",
-			f"{d[s].lemma_}/VERB|vtv:{d[s].lemma_} to _{d[e-1].tag_}",]}} ) ,
+			f"{d[s].lemma_}/VERB|vtv:_{d[s].lemma_} to _{d[e-1].tag_}",]}} ) ,
 	"vg": lambda d,s,e,tag: d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vg|{d[s].lemma_} {d[e-1].text}", f"{d[s].lemma_}:VERB:vg|_{d[s].lemma_} _VBG", f"{d[s].lemma_}:VERB|vg", f"{d[e-1].lemma_}:VERB|~vg", f"{d[e-1].lemma_}:VERB:~vg|{d[s].lemma_}",
-				f"{d[s].lemma_}/VERB|vg:{d[s].lemma_} _{d[e-1].tag_}",]}}) , 
+				f"{d[s].lemma_}/VERB|vg:_{d[s].lemma_} _{d[e-1].tag_}",]}}) , 
 	"vdpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vdpg|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vdpg", f"_{d[s].lemma_} {d[s+1:e-1].text} _VBG",
-				f"{d[s].lemma_}/VERB|vdpg:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",] }}),
+				f"{d[s].lemma_}/VERB|vdpg:_{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",] }}),
 	}
 
 def postag_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"postag[{start},{end}):{tag}": SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) } ) ): 
@@ -956,11 +956,11 @@ def skenp_func_kp(doc, start, end, tag): # skenp_func_kp	= lambda doc, start, en
 	if tag in ('vnpn'): # take _NP into account, added 2023.2.14
 		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}", f"{doc[end-1].text.lower()}/NOUN|{tag}:" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower()])
 	if tag in ("vnpe"): # take _NP for granted
-		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}", f"{doc[end-1].lemma_}/VERB|vpne:" +span_NP(doc[start:end]),])
-	if tag in ("vn"): nac.extend([f"{doc[start].lemma_}/VERB|vn:{doc[start].lemma_} _NP"])
-	if tag == "vna": nac.extend([f"{doc[start].lemma_}/VERB|vna:{doc[start].lemma_} _NP _ADJ"])
-	if tag in ("vnn"): nac.extend([f"{doc[start].lemma_}/VERB|vnn:{doc[start].lemma_} _NP _NP"])
-	if tag in ("vne"): nac.extend([f"{doc[start].lemma_}/VERB|vne:{doc[start].lemma_} _NP _VBN"])
+		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}", f"{doc[end-1].lemma_}/VERB|vnpe:_" +span_NP(doc[start:end]),])
+	if tag in ("vn"): nac.extend([f"{doc[start].lemma_}/VERB|vn:_{doc[start].lemma_} _NP"])
+	if tag == "vna": nac.extend([f"{doc[start].lemma_}/VERB|vna:_{doc[start].lemma_} _NP _ADJ"])
+	if tag in ("vnn"): nac.extend([f"{doc[start].lemma_}/VERB|vnn:_{doc[start].lemma_} _NP _NP"])
+	if tag in ("vne"): nac.extend([f"{doc[start].lemma_}/VERB|vne:_{doc[start].lemma_} _NP _VBN"])
 	doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac":nac} })
 
 trp3_func_kp = { #drink:VERB:dobj:NOUN:water:amod:ADJ safe
