@@ -39,7 +39,7 @@ def run(infile, host:str='172.17.0.1', port:int=3309, db:str='nacp'):
 	name = infile.split('.jsonlg' if '.jsonlg' in infile else '.')[0] 
 	start = time.time()
 	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db=db)
-	print ("started:", infile , my_conn,  flush=True)
+	print ("sntjson-fts started:", infile , my_conn,  flush=True)
 	with my_conn.cursor() as cursor: 
 		cursor.execute(f"drop TABLE if exists {name}_snt")
 		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid bigint primary key, snt text not null, kps text not null, map JSON, frames text,  fulltext key `snt`(`snt`), fulltext key `kps`(`kps`), fulltext key `frames`(`frames`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
