@@ -26,13 +26,19 @@ config = {
 				  "patterns": [
 					#"(^([^_]+)_[a-z]+[,\\.$]?)",  
 					"(^[^_]+)",   # first lex
-					#"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)$", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
+					"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
 					#"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",  # remove _NP5,  _NP5 => _NP 
-					"(_[a-zA-Z,\\-\\.\\'\\$\\*]+)",  # _^ _ADJ _, _NOUN _VERB
+					"(_[a-zA-Z,\\-\\.\\'\\$\\*]+)",  # _^ _ADJ _, _NOUN _VERB , _open/VERB 
 					#"(_[^\\w]+)_",
 					#"([^\\w])_"
 				  ]
 				},
+				"postag_filter1": {
+					  "type": "pattern_replace",
+					  "pattern": "(^_([a-z]+)_([VERB|NOUN|ADJ|ADV]))",
+					  "replacement": "$2/$3",  # _open_VERB => open/VERB
+					  "all": False
+					},
 				"postag_filter2": {
 				  "type": "word_delimiter",
 				  "type_table": [
@@ -40,6 +46,7 @@ config = {
 					", => ALPHA",
 					"$ => ALPHA",
 					"* => ALPHA",
+					"/ => ALPHA",
 					"_ => ALPHA",
 					". => ALPHA",
 					"- => ALPHA",
@@ -64,7 +71,7 @@ config = {
 				}
 			  },
 			  "analyzer": {
-				"postag_ana": {"filter": ["postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
+				"postag_ana": {"filter": ["postag_filter", "postag_filter1", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
 				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
 				"path_ana3": {"type": "custom", "tokenizer": "path-tokenizer3"},
 				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
@@ -469,19 +476,15 @@ def init(idxname):
 	print(">>finished " + idxname )
 
 def testana(index:str='test'):
-	arr = requests.post(f"http://{requests.eshost}/{index}/_analyze", json={
+	arr = requests.post(f"http://sntvec.wrask.com:9200/{index}/_analyze", json={
   "analyzer": "postag_ana",
-  "text": "booked_,_VBD_book_VERB_NP5"
-}).json() 
+  "text": "booked_book_VERB_VBD_NP5"
+}).json()
 	for t in arr['tokens']:
 		print (t) 
 
 if __name__ == "__main__": 
-	#print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
-	#print ( sqlrow("show tables")) 
-	#print (hybchunk(index='clec')) 
-	#init("test")
-	fire.Fire(init) 
+	fire.Fire({"init":init,"test":testana}) 
 	
 '''
 {'tokens': [{'token': 'booked', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
@@ -621,4 +624,34 @@ POST /clec/_analyze
   "analyzer": "postag_ana",
   "text": "booked_book_VBD_VERB_."
 }
+
+GET /gzjc/_analyze
+{
+  "analyzer": "postag_ana", 
+  "text": "foxes jumped_jump_VERB_VBD lazy dogs"
+}
+
+GET /_analyze
+{
+  "tokenizer": "whitespace",
+  "filter": [
+    {
+      "type": "pattern_replace",
+      "pattern": "((^[^_]+)_([a-z]+)_([VERB|NOUN|ADJ|ADV]+)_.*)",
+      "replacement": "$3/$4",
+      "all": false
+    }
+  ],
+  "text": "foxes jumped_jump_VERB_VBD lazy dogs"
+}
+
+ubuntu@dicvec-scivec-jukuu-com-flair-64-245:~/cikuu/pypi/so$ python __init__.py init test
+>>finished test
+ubuntu@dicvec-scivec-jukuu-com-flair-64-245:~/cikuu/pypi/so$ python __init__.py test
+{'token': 'booked', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
+{'token': 'book/VERB', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
+{'token': '_book', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
+{'token': '_VERB', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
+{'token': '_VBD', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
+{'token': '_NP', 'start_offset': 0, 'end_offset': 24, 'type': 'word', 'position': 0}
 '''
\ No newline at end of file
