@@ -98,10 +98,21 @@ def redis_even_odd(arr:list=['even line','odd line'], asdic:bool=False): return
 four_int = lambda four, denom=100: [int( int(a)/denom) for a in four]
 xy = lambda four : [f"{a},{b}" for a in range(four[0], four[2]+2) for b in range( four[1], four[3] + 2) ] # xy_to_item
 @app.post('/redis/penly/xy_to_item', tags=["redis"])
-def penly_xy_to_items(arr:list=[[861,1577,11712,2214,"{\"item\":\"fill-1\",\"key\":\"B\"}"],[861,2239,11712,2706,"fill-2"],[861,2731,11712,3297,"fill-3"],[861,3321,11712,3801,"fill-4"],[861,3826,11712,4306,"fill-5"],[861,4330,11712,4798,"fill-6"],[861,4822,11712,5376,"fill-7"],[861,5401,11712,5905,"fill-8"],[861,5930,11712,6336,"fill-9"],[861,6360,11712,6988,"fill-10"],[861,7012,11712,7517,"fill-11"],[861,7541,11712,8009,"fill-12"],[861,8033,11712,8562,"fill-13"],[861,8587,11712,9104,"fill-14"],[861,9128,11712,9596,"fill-15"],[861,9620,11712,10186,"fill-16"],[861,10211,11712,10740,"fill-17"],[861,10765,11712,11232,"fill-18"],[861,11257,11712,11774,"fill-19"],[861,11798,11712,12303,"fill-20"],[861,12327,11712,12868,"fill-21"],[861,12893,11712,13398,"fill-22"],[861,13422,11712,13939,"fill-23"],[861,13963,11712,14468,"fill-24"],[861,14492,11712,14985,"fill-25"],[861,15009,11712,15661,"fill-26"]], denom:int=100,key:str="page:0.100.0:xy_to_item"): 
-	''' submit data into the permanent store, updated 2021.10.8 '''
-	redis.r.set("page:"+key.split(':')[1]+":rect_position", json.dumps(arr))
-	return [redis.r.hset(key, k, tag) for x1,y1,x2,y2,tag in arr for k in xy( ( int(x1/denom), int(y1/denom), int(x2/denom), int(y2/denom)) )]
+def penly_xy_to_items(arr:list=[[861,1577,11712,2214,"{\"item\":\"fill-1\",\"key\":\"B\"}"],[861,2239,11712,2706,"fill-2"],[861,2731,11712,3297,"fill-3"],[861,3321,11712,3801,"fill-4"],[861,3826,11712,4306,"fill-5"],[861,4330,11712,4798,"fill-6"],[861,4822,11712,5376,"fill-7"],[861,5401,11712,5905,"fill-8"],[861,5930,11712,6336,"fill-9"],[861,6360,11712,6988,"fill-10"],[861,7012,11712,7517,"fill-11"],[861,7541,11712,8009,"fill-12"],[861,8033,11712,8562,"fill-13"],[861,8587,11712,9104,"fill-14"],[861,9128,11712,9596,"fill-15"],[861,9620,11712,10186,"fill-16"],[861,10211,11712,10740,"fill-17"],[861,10765,11712,11232,"fill-18"],[861,11257,11712,11774,"fill-19"],[861,11798,11712,12303,"fill-20"],[861,12327,11712,12868,"fill-21"],[861,12893,11712,13398,"fill-22"],[861,13422,11712,13939,"fill-23"],[861,13963,11712,14468,"fill-24"],[861,14492,11712,14985,"fill-25"],[861,15009,11712,15661,"fill-26"]], denom:int=100,key:str="page:0.100.0:xy_to_item",tsd:str="0"): 
+	''' 
+	submit data into the permanent store, updated 2021.10.8 
+	tsd=1 拓思德，回转换为腾千里格式
+	'''
+	if tsd=='1':
+		##拓思德最大像素 5600*7920
+		## 腾千里 a4 最大像素  13779*19488  13779=210*100/1.524 19488=297*100/1.524
+		dt=  2.4606 ##210*100/(1.524*5600) 
+		arr2 = [[int(x1*dt), int(y1*dt), int(x2*dt), int(y2*dt),tag] for x1,y1,x2,y2,tag in arr ]
+		redis.r.set("page:"+key.split(':')[1]+":rect_position", json.dumps(arr2))
+		return [redis.r.hset(key, k, tag) for x1,y1,x2,y2,tag in arr for k in xy( ( int(x1*dt/denom), int(y1*dt/denom), int(x2*dt/denom), int(y2*dt/denom)) )]
+	else:
+		redis.r.set("page:"+key.split(':')[1]+":rect_position", json.dumps(arr))
+		return [redis.r.hset(key, k, tag) for x1,y1,x2,y2,tag in arr for k in xy( ( int(x1/denom), int(y1/denom), int(x2/denom), int(y2/denom)) )]
 
 if __name__ == '__main__':	
 	pass
\ No newline at end of file
